==> haskell-postgresql-libpq-0.9.4.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-libpq
version:              0.9.4.2
visibility:           public
id:                   postgresql-libpq-0.9.4.2-3YJLZoe2oEYMws18ADG1o
key:                  postgresql-libpq-0.9.4.2-3YJLZoe2oEYMws18ADG1o
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/phadej/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  4bb367dfb2a70a816515a817b095e59d
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

import-dirs:          /usr/lib/ghc-8.8.1/site-local/postgresql-libpq-0.9.4.2
library-dirs:
    /usr/lib/ghc-8.8.1/site-local/postgresql-libpq-0.9.4.2 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/postgresql-libpq-0.9.4.2
hs-libraries:         HSpostgresql-libpq-0.9.4.2-3YJLZoe2oEYMws18ADG1o
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.13.0.0 bytestring-0.10.9.0 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-libpq-0.9.4.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-libpq
version:              0.9.4.2
visibility:           public
id:                   postgresql-libpq-0.9.4.2-BkXb59M2bvIJ5yWIp9Q1Nd
key:                  postgresql-libpq-0.9.4.2-BkXb59M2bvIJ5yWIp9Q1Nd
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/phadej/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  7fcb211f6fd8dfe716682d5cb6cf32e3
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

import-dirs:          /usr/lib/ghc-8.8.2/site-local/postgresql-libpq-0.9.4.2
library-dirs:
    /usr/lib/ghc-8.8.2/site-local/postgresql-libpq-0.9.4.2 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/postgresql-libpq-0.9.4.2
hs-libraries:         HSpostgresql-libpq-0.9.4.2-BkXb59M2bvIJ5yWIp9Q1Nd
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.13.0.0 bytestring-0.10.10.0 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
